#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Copyright 2020 University of Liège
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# simple test on a square : heat source + anisotropy

import heat as h
import heat.utils as u
import tbox
import tbox.gmsh as gmsh
from fwk.testing import *

def main():

    # mesh a unit square
    pars = {'Lx' : 1 , 'Ly' : 1, 'Nx' : 30, 'Ny' : 30}
    msh = gmsh.MeshLoader("../../models/rect_stru.geo",__file__).execute(**pars)
    gmshWriter = tbox.GmshExport(msh)
    pbl = h.Problem(msh)

    # medium/boundary conditions
    pbl.add(h.Source(msh, "S1", tbox.Fct0C(1.0))) # heat src

    pbl.add(h.Medium(msh, "S1", tbox.Fct2C(2.0,1.0,-1.0))) # anisotropy

    pbl.add(h.Dirichlet(msh,"Left", 0.))
    pbl.add(h.Dirichlet(msh,"Right", 0.))
    pbl.add(h.Dirichlet(msh,"Bottom", 0.))
    pbl.add(h.Dirichlet(msh,"Top", 0.))

    # solve problem
    solver = u.solve(pbl, gmshWriter)

    # check results
    x1,y1,T1 = u.getTemp(solver,"S1")
    tests = CTests()
    tests.add(CTest('max(T)', max(T1), 0.053841, 1e-2))
    tests.run()


if __name__ == "__main__":
    main()
